@@ -325,11 +325,12 @@ impl<'a> VariantConfig<'a> {
                     quote!(#crate_root::TagTree::Leaf(<() as #crate_root::AsnType>::TAG),)
                 }
                 syn::Fields::Named(_) => {
-                    let error_message = format!("{}'s fields is not a valid \
+                    let error_message = format!(
+                        "{}'s fields is not a valid \
                         order of ASN.1 tags, ensure that your field's tags and \
                         OPTIONALs are correct.",
-                            self.variant.ident
-                        );
+                        self.variant.ident
+                    );
 
                     quote!({
                         const FIELD_LIST: &'static [#crate_root::TagTree] = &[#(#field_tags,)*];
@@ -411,7 +412,17 @@ impl<'a> FieldConfig<'a> {
 
         let encode_op = if self.tag.is_some() || self.container_config.automatic_tags {
             if self.tag.as_ref().map_or(false, |tag| tag.explicit) {
-                quote!(encoder.encode_explicit_prefix(#tag, &self.#field)?;)
+                let encode = quote!(encoder.encode_explicit_prefix(#tag, &self.#field)?;);
+                if self.is_option_type() {
+                    let none = &self.container_config.option_type.none_variant;
+                    quote! {
+                        if !matches!(&#this #field, #none) {
+                            #encode
+                        }
+                    }
+                } else {
+                    encode
+                }
             } else {
                 quote!(#this #field.encode_with_tag(encoder, #tag)?;)
             }
@@ -441,6 +452,7 @@ impl<'a> FieldConfig<'a> {
         let or_else = match self.default {
             Some(Some(ref path)) => quote! { .unwrap_or_else(|_| #path ()) },
             Some(None) => quote! { .unwrap_or_default() },
+            None if self.is_option_type() => quote! { .ok() },
             None => {
                 let ident = format!(
                     "{}.{}",
